@@ -109,7 +109,7 @@ public class UserFeedAction extends AbstractXingAction {
         {
         	String token = req.getParameter("testToken");
         	String secret = req.getParameter("testSecret");
-        	if (!Strings.isEmpty(token) && !Strings.isEmpty(secret)) {
+        	if (Strings.isNotEmpty(token) && Strings.isNotEmpty(secret)) {
         		xingOAuthAccess = getXingOAuthAccess(token, secret, req.getSession());
         	} else {
         		xingOAuthAccess = getXingOAuthAccess(req);
